@@ -9,30 +9,27 @@
 */
 
 #include "jobs.h"
-
-#include "lokalize_debug.h"
-
 #include "catalog.h"
 #include "diff.h"
+#include "lokalize_debug.h"
 #include "prefs_lokalize.h"
 #include "project.h"
 #include "version.h"
 
-#include "stemming.h"
-
 #include <QDir>
 #include <QElapsedTimer>
 #include <QFile>
 #include <QMap>
+#include <QMutex>
 #include <QRegularExpression>
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QStandardPaths>
 #include <QStringBuilder>
-
-#include <iostream>
+#include <QThreadPool>
 
 #include <math.h>
+
 using namespace TM;
 
 QThreadPool *TM::threadPool()
